@@ -1,5 +1,3 @@
-context("funs-predicates")
-
 test_that("all_exprs() creates intersection", {
   expect_identical(all_exprs(am == 1), quo(am == 1))
 
@@ -15,8 +13,6 @@ test_that("any_exprs() creates union", {
 })
 
 test_that("all_exprs() gives meaningful error messages", {
-  verify_output(test_path("test-funs-predicates-errors.txt"), {
-    all_exprs()
-    any_exprs()
-  })
+  expect_snapshot(error = TRUE, all_exprs())
+  expect_snapshot(error = TRUE, any_exprs())
 })
