@@ -1,5 +1,3 @@
-context("utils")
-
 test_that("quo_is_variable_reference handles .data",{
   expect_true(quo_is_variable_reference(quo(x)))
   expect_true(quo_is_variable_reference(quo(.data$x)))
@@ -9,8 +7,6 @@ test_that("quo_is_variable_reference handles .data",{
 })
 
 test_that("check_pkg() give meaningful error messages", {
-  verify_output(test_path("test-utils-errors.txt"), {
-    dplyr:::check_pkg("`__foobarbaz__`", "foobar a baz")
-    dplyr:::check_pkg("`__foobarbaz__`", "foobar a baz", install = FALSE)
-  })
+  expect_snapshot(error = TRUE, dplyr:::check_pkg("`__foobarbaz__`", "foobar a baz"))
+  expect_snapshot(error = TRUE, dplyr:::check_pkg("`__foobarbaz__`", "foobar a baz", install = FALSE))
 })
